function savePatterns(gaitPatterns, fileDirectory)

% savePatterns saves data of gait patterns into CSV files.
%
% Files are saved to a given directory into subdirectories 
% determined by indexes-identifiers of participants and shoe types.
% These indexes are taken from names of .CSV files with raw data of gait
% measurements that are behind patterns.
%
% The name of a file with pattern data differs 
% only in the additional PTRN component from
% the name of the corresponding file with measurement data.
% For example:
% - 324.m.2.spr.13-12-11.17.ptrn.csv : file with pattern data
% - 324.m.2.spr.13-12-11.17.csv : file with measurement data
% This 
% - allows users to easily differentiate files
% - allows files of both types to coexist in the same directory, 
%   even though this is not recoomended
%
% Column headers are saved in the first line of a file.
%
%         
% Created on May 15, 2022
% 
% Author: Marek Parfieniuk
%
% Copyright (c) 2021 Marek Parfieniuk
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>



for measurementIndex = 1 : length(gaitPatterns.fileName)
%for measurementIndex = 1 : 208
    fileName = gaitPatterns.fileName{measurementIndex};
    participantIndex = fileName(1 : 3);
    footwearIndex = fileName(7);
    
    %foutDir = 'h:/gaitPatternsInCSVFiles';
    foutDir = fileDirectory;
    
    status = mkdir(foutDir, [participantIndex '/' footwearIndex '/']);
    if (status == 0)
        error('Cannot create a directory for files');
    end
    
    foutPath = [foutDir '/' participantIndex '/' footwearIndex '/' fileName(1 : (end - 3)) 'ptrn.csv'];
    
    fprintf("Creating file %s\n", foutPath)    
    
    fout = fopen(foutPath, 'w+');
            %fprintf(fout, 'x_coordinate_of_cop_1st_plate,y_coordinate_of_cop_1st_plate,medio_lateral_grf_1st_plate,anterior_posterior_grf_1st_plate,vertical_grf_1st_plate,vertical_torque_1st_plate,x_coordinate_of_cop_2nd_plate,y_coordinate_of_cop_2nd_plate,medio_lateral_grf_2nd_plate,anterior_posterior_grf_2nd_plate,vertical_grf_2nd_plate,vertical_torque_2nd_plate\n');
    %fprintf(fout, 'leftVForce,leftAPForce,leftMLForce,rightVForce,rightAPForce,rightMLForce,leftRawSampleIndex,rightRawSampleIndex\n');
    fprintf(fout, ['leftVForce,leftAPForce,leftMLForce,rightVForce,rightAPForce,rightMLForce' ...
        ',leftVMean,leftAPMean,leftMLMean,rightVMean,rightAPMean,rightMLMean' ... 
        ',leftRawSampleIndex,rightRawSampleIndex\n']);
    
    sampleCount = size(gaitPatterns.leftVForce, 2);    
    for sampleIndex = 1 : sampleCount
        ending = '';
        if (sampleIndex == 1)
            %ending = [',' int2str(gaitPatterns.leftStrikeIndex(recordIndex)) ',' int2str(gaitPatterns.rightStrikeIndex(recordIndex))];
            ending = sprintf(',%.2f,%.2f,%.2f,%.2f,%.2f,%.2f,%d,%d', ...
                gaitPatterns.leftVStrikeMean(measurementIndex), gaitPatterns.leftAPStrikeMean(measurementIndex), gaitPatterns.leftMLStrikeMean(measurementIndex), ...
                gaitPatterns.rightVStrikeMean(measurementIndex), gaitPatterns.rightAPStrikeMean(measurementIndex), gaitPatterns.rightMLStrikeMean(measurementIndex), ...
                gaitPatterns.leftStrikeIndex(measurementIndex), gaitPatterns.rightStrikeIndex(measurementIndex));
            
       %     keyboard
        end
        if (sampleIndex == sampleCount)
            ending = sprintf(',%.2f,%.2f,%.2f,%.2f,%.2f,%.2f,%d,%d', ...
                gaitPatterns.leftVOffMean(measurementIndex), gaitPatterns.leftAPOffMean(measurementIndex), gaitPatterns.leftMLOffMean(measurementIndex), ...
                gaitPatterns.rightVOffMean(measurementIndex), gaitPatterns.rightAPOffMean(measurementIndex), gaitPatterns.rightMLOffMean(measurementIndex), ...
                gaitPatterns.leftOffIndex(measurementIndex), gaitPatterns.rightOffIndex(measurementIndex));
        end
            
        %fprintf(fout, '%.16f,%.16f,%.16f,%.16f,%.16f,%.16f%s\n' ...
        fprintf(fout, "%.6f,%.6f,%.6f,%.6f,%.6f,%.6f%s\n" ...
            , gaitPatterns.leftVForce(measurementIndex, sampleIndex) ...
            , gaitPatterns.leftAPForce(measurementIndex, sampleIndex) ...
            , gaitPatterns.leftMLForce(measurementIndex, sampleIndex) ...
            , gaitPatterns.rightVForce(measurementIndex, sampleIndex) ...
            , gaitPatterns.rightAPForce(measurementIndex, sampleIndex) ...
            , gaitPatterns.rightMLForce(measurementIndex, sampleIndex) ...
            , ending);                                
    end
    fclose(fout);    
end